@@ -26,6 +26,7 @@ import csv
 from canalyst_candas.version import __version__ as version
 import pickle
 import pkg_resources
+from canalyst_candas.exceptions import BaseCandasException
 
 from canalyst_candas.configuration.config import Config, resolve_config
 import urllib3
@@ -74,6 +75,11 @@ BRAND_CONFIG_DEFAULTS = {
     "logo_path": pkg_resources.resource_filename(__name__, "images/logo.png"),
 }
 
+SAMPLE_MODEL_PATH = {
+    "drivers_path": pkg_resources.resource_filename(__name__, "sample_data/drivers"),
+    "models_path": pkg_resources.resource_filename(__name__, "sample_data/models"),
+}
+
 
 class BulkDataKeys(Enum):
     FORECAST_DATA = "forecast-data"
@@ -183,6 +189,7 @@ class Getter:
             "s3",
             aws_access_key_id=self.config.s3_access_key_id,
             aws_secret_access_key=self.config.s3_secret_key,
+            verify=config.verify_ssl,
         )
 
     def get_s3_file(self, to_filename, from_filename):
@@ -296,6 +303,20 @@ class Getter:
         return df
 
 
+def get_test_data_set(csv_type: BulkDataFileType, ticker: str):
+    """
+    Fetches data from the test data set in the models folder
+    """
+    csv_type = csv_type.value.replace("-", "_")
+    csv_types = ["historical_data", "forecast_data", "name_index"]
+    if csv_type not in csv_types:
+        raise BaseCandasException("CSV type is not one of the available options")
+    model_path = SAMPLE_MODEL_PATH["models_path"]
+    file_name = f"{model_path}/{ticker}_{csv_type}.csv"
+    df = pd.read_csv(file_name)
+    return df
+
+
 def get_data_set_from_mds(
     bulk_data_key: BulkDataKeys,
     file_type: str,
@@ -304,6 +325,7 @@ def get_data_set_from_mds(
     auth_headers: Dict[str, str],
     log: LogFile,
     mds_host: str = settings.MDS_HOST,
+    verify_ssl=settings.VERIFY_SSL,
 ):
     """
     Pulls a bulk data file from the MDS at the equity-model endpoint and returns it in a dataframe.
@@ -327,8 +349,18 @@ def get_data_set_from_mds(
         model_version,
         mds_host,
     )
-
-    response = get_request(url, auth_headers, log)
+    response = get_request(url, auth_headers, log, verify_ssl)
+    # parquet not available: fallback to csv
+    if response is None:
+        url = _get_mds_bulk_data_url(
+            bulk_data_key,
+            "csv",  # file_type set to csv
+            csin,
+            model_version,
+            mds_host,
+        )
+        response = get_request(url, auth_headers, log, verify_ssl)
+        file_type = "csv"
 
     if file_type == BulkDataFileType.CSV.value:
         csv_string = response.content.decode("utf-8")
@@ -507,13 +539,14 @@ def send_scenario(
     csin="",
     latest_version="",
     mds_host=settings.MDS_HOST,
+    verify_ssl=settings.VERIFY_SSL,
 ):
     """
     Makes a POST request for scenario to the MDS
     """
     if csin == "" or latest_version == "":
         csin, latest_version = get_company_info_from_ticker(
-            ticker, auth_headers, logger, mds_host
+            ticker, auth_headers, logger, mds_host, verify_ssl
         )
     scenario_url = (
         f"{mds_host}/{SCENARIO_URL.format(csin=csin, version=latest_version)}"
@@ -521,7 +554,7 @@ def send_scenario(
     # print("scenario_url: " + scenario_url)
     try:
         scenario_response = post_request(
-            url=scenario_url, headers=auth_headers, json=data
+            url=scenario_url, headers=auth_headers, json=data, verify_ssl=verify_ssl
         )
     except:
         return None
@@ -609,14 +642,20 @@ def get_name_index_from_csv(ticker, config):
     return df_index
 
 
-def get_scenarios(ticker, auth_headers, logger: LogFile, mds_host=settings.MDS_HOST):
+def get_scenarios(
+    ticker,
+    auth_headers,
+    logger: LogFile,
+    mds_host=settings.MDS_HOST,
+    verify_ssl=settings.VERIFY_SSL,
+):
     if ticker == "":
         ticker = ticker
     url = f"{mds_host}/api/scenarios/"
     csin, latest_version = get_company_info_from_ticker(
-        ticker, auth_headers, logger, mds_host
+        ticker, auth_headers, logger, mds_host, verify_ssl
     )
-    response_content = get_request_json_content(url, auth_headers, logger)
+    response_content = get_request_json_content(url, auth_headers, logger, verify_ssl)
     res = response_content.get("results")
     list_out = []
     for i in res:
@@ -630,27 +669,33 @@ def get_scenarios(ticker, auth_headers, logger: LogFile, mds_host=settings.MDS_H
     return df_data
 
 
-def post_request(url, headers, json):
+def post_request(url, headers, json, verify_ssl):
     """
     POST request helper function
 
     Uses timer to account for throttle limits.
     """
-    response = requests.post(url=url, headers=headers, json=json, verify=False)
+    response = requests.post(url=url, headers=headers, json=json, verify=verify_ssl)
     if check_throttle_limit(response):
-        response = requests.post(url=url, headers=headers, json=json, verify=False)
+        response = requests.post(url=url, headers=headers, json=json, verify=verify_ssl)
 
     return response
 
 
 def get_company_info_from_ticker(
-    ticker, auth_headers, logger: LogFile, mds_host=settings.MDS_HOST
+    ticker,
+    auth_headers,
+    logger: LogFile,
+    mds_host=settings.MDS_HOST,
+    verify_ssl=settings.VERIFY_SSL,
 ):
     """
     Get CSIN and latest version for a ticker
     """
     company_url = f"{mds_host}/{CSIN_URL.format(ticker=quote_plus(ticker))}"
-    response_content = get_request_json_content(company_url, auth_headers, logger)
+    response_content = get_request_json_content(
+        company_url, auth_headers, logger, verify_ssl
+    )
 
     json = response_content.get("results")[0]
     csin: str = json.get("csin")
@@ -662,13 +707,19 @@ def get_company_info_from_ticker(
 
 
 def get_csin_from_ticker(
-    ticker, auth_headers, logger: LogFile, mds_host=settings.MDS_HOST
+    ticker,
+    auth_headers,
+    logger: LogFile,
+    mds_host=settings.MDS_HOST,
+    verify_ssl=settings.VERIFY_SSL,
 ):
     """
     Get CSIN for ticker
     """
     company_url = f"{mds_host}/{CSIN_URL.format(ticker=quote_plus(ticker))}"
-    response_content = get_request_json_content(company_url, auth_headers, logger)
+    response_content = get_request_json_content(
+        company_url, auth_headers, logger, verify_ssl
+    )
     json = response_content.get("results")[0]
     csin = json.get("csin")
     return csin
@@ -686,7 +737,9 @@ def get_excel_model(config, logger, ticker="", download_dir=""):
     else:
         default_dir = download_dir
 
-    csin = get_csin_from_ticker(ticker, auth_headers, logger, mds_host)
+    csin = get_csin_from_ticker(
+        ticker, auth_headers, logger, mds_host, config.verify_ssl
+    )
 
     client = GraphqlClient(endpoint=f"{wp_host}/model-workbooks")
 
@@ -717,7 +770,7 @@ def get_excel_model(config, logger, ticker="", download_dir=""):
 
     # Synchronous request
     data = client.execute(
-        query=query, variables=variables, headers=auth_headers, verify=False
+        query=query, variables=variables, headers=auth_headers, verify=config.verify_ssl
     )
     url = data["data"]["modelSeries"]["latestModel"]["variantsByDimensions"][0][
         "downloadUrl"
@@ -741,7 +794,7 @@ def get_excel_model(config, logger, ticker="", download_dir=""):
         os.rename(file_name, backup_name)
         print("Backup to: " + backup_name)
 
-    r = requests.get(url, headers=auth_headers, verify=False)
+    r = requests.get(url, headers=auth_headers, verify=config.verify_ssl)
 
     with open(file_name, "wb") as f:
         f.write(r.content)
@@ -772,14 +825,16 @@ def get_forecast_url(csin, latest_version, mds_host=settings.MDS_HOST):
     )
 
 
-def get_forecast_url_data(res_dict, ticker, auth_headers, log):
+def get_forecast_url_data(
+    res_dict, ticker, auth_headers, log, verify_ssl=settings.VERIFY_SSL
+):
     list_out = []
     url = res_dict["self"]
 
-    res_loop = get_request(url, auth_headers, log)
+    res_loop = get_request(url, auth_headers, log, verify_ssl)
     url = res_loop.json()["data_points"]
 
-    res_loop = get_request(url, auth_headers, log)
+    res_loop = get_request(url, auth_headers, log, verify_ssl)
     # try:
     next_url = res_loop.json()["next"]
     # except:
@@ -825,7 +880,7 @@ def get_forecast_url_data(res_dict, ticker, auth_headers, log):
             list_out.append(df)
         url = next_url
         try:
-            res_loop = get_request(url, auth_headers, log)
+            res_loop = get_request(url, auth_headers, log, verify_ssl)
             next_url = res_loop.json()["next"]
         except:
             url = None
@@ -833,15 +888,19 @@ def get_forecast_url_data(res_dict, ticker, auth_headers, log):
 
 
 def get_scenario_url_data(
-    res_dict, ticker, auth_headers, default_dir=settings.DEFAULT_DIR
+    res_dict,
+    ticker,
+    auth_headers,
+    default_dir=settings.DEFAULT_DIR,
+    verify_ssl=settings.VERIFY_SSL,
 ):
     log = LogFile(default_dir=default_dir)
     url = res_dict["self"]
 
-    res_loop = get_request(url, auth_headers, log)
+    res_loop = get_request(url, auth_headers, log, verify_ssl)
     url = res_loop.json()["data_points"]
 
-    res_loop = get_request(url, auth_headers, log)
+    res_loop = get_request(url, auth_headers, log, verify_ssl)
 
     try:
         res_data = res_loop.json()["results"]
@@ -881,7 +940,7 @@ def get_scenario_url_data(
             df = pd.DataFrame.from_dict(dict_out, orient="index").T
             list_out.append(df)
         try:
-            res_loop = get_request(url, auth_headers, log)
+            res_loop = get_request(url, auth_headers, log, verify_ssl)
             res_data = res_loop.json()["results"]
             url = res_loop.json()["next"]
         except:
@@ -889,15 +948,15 @@ def get_scenario_url_data(
     return pd.concat(list_out)
 
 
-def get_request(url, headers, logger):
+def get_request(url, headers, logger, verify_ssl=settings.VERIFY_SSL):
     """
     Wrapper for a GET request
 
     Handles throttle limits by using a timer
     """
-    response = requests.get(url=url, headers=headers, verify=False)
+    response = requests.get(url=url, headers=headers, verify=verify_ssl)
     if check_throttle_limit(response, logger):
-        response = requests.get(url=url, headers=headers, verify=False)
+        response = requests.get(url=url, headers=headers, verify=verify_ssl)
 
     try:
         response.raise_for_status()
@@ -985,14 +1044,14 @@ def create_drivers_dot(
         return path_name
     else:
         csin, version = get_company_info_from_ticker(
-            ticker, auth_headers, logger, config.mds_host
+            ticker, auth_headers, logger, config.mds_host, config.verify_ssl
         )
         url = (
             f"{config.mds_host}/api/equity-model-series/{csin}/equity-models/"
             f"{version}/time-series/{time_series}/forecast-data-points/"
         )
 
-        r = requests.get(url, headers=auth_headers, verify=False)
+        r = requests.get(url, headers=auth_headers, verify=config.verify_ssl)
         json = r.json().get("results")[0]
         name = json["period"]["name"]
         url = (
@@ -1002,7 +1061,7 @@ def create_drivers_dot(
         )
 
         print(url)
-        r = requests.get(url, headers=auth_headers, verify=False)
+        r = requests.get(url, headers=auth_headers, verify=config.verify_ssl)
         with open(path_name, "wb") as f:
             f.write(r.content)
         return path_name
@@ -1018,7 +1077,13 @@ def get_model_url(ticker, wp_host=settings.WP_HOST):
 
 
 # retrieve latest equity model from API
-def get_model_info(ticker, auth_headers, log: LogFile, mds_host=settings.MDS_HOST):
+def get_model_info(
+    ticker,
+    auth_headers,
+    log: LogFile,
+    mds_host=settings.MDS_HOST,
+    verify_ssl=settings.VERIFY_SSL,
+):
     """
     Retrieve latest equity model information and historical datapoints endpoint url
     """
@@ -1026,7 +1091,9 @@ def get_model_info(ticker, auth_headers, log: LogFile, mds_host=settings.MDS_HOS
 
     company_url = f"{mds_host}/{CSIN_URL.format(ticker=quote_plus(ticker))}"
 
-    company_response = get_request_json_content(company_url, auth_headers, log)
+    company_response = get_request_json_content(
+        company_url, auth_headers, log, verify_ssl
+    )
     json = company_response.get("results")[0]
     csin = json.get("csin")
     company = json.get("company", {}).get("name")
@@ -1045,6 +1112,7 @@ def get_model_info(ticker, auth_headers, log: LogFile, mds_host=settings.MDS_HOS
         mds_host,
         log,
         HISTORICAL_PERIODS_TO_FETCH,
+        verify_ssl,
     )
 
     model_info[ticker] = (
@@ -1071,9 +1139,12 @@ def get_historical_periods(
     mds_host,
     log,
     num_of_periods_to_fetch=HISTORICAL_PERIODS_TO_FETCH,
+    verify_ssl=settings.VERIFY_SSL,
 ):
     periods_url = f"{mds_host}/{PERIODS_URL.format(csin=csin, version=version)}"
-    periods_response = get_request_json_content(periods_url, auth_headers, log)
+    periods_response = get_request_json_content(
+        periods_url, auth_headers, log, verify_ssl
+    )
     periods_json = periods_response.get("results")
     periods = [period.get("name") for period in periods_json[:num_of_periods_to_fetch]]
 
@@ -1096,6 +1167,7 @@ def crawl_company_pages(
     auth_headers,
     logger: LogFile,
     default_dir=settings.DEFAULT_DIR,
+    verify_ssl=settings.VERIFY_SSL,
 ):
     """
     Retreive data from url and subsequent pages.
@@ -1104,7 +1176,9 @@ def crawl_company_pages(
 
     page_number = 1
     while next_url is not None:
-        response_content = get_request_json_content(next_url, auth_headers, logger)
+        response_content = get_request_json_content(
+            next_url, auth_headers, logger, verify_ssl
+        )
         response = response_content.get(key_name)
         next_url = response_content.get(next_name)
         files_path = f"{default_dir}/DATA/{file_ticker}"
@@ -1469,14 +1543,27 @@ def calendar_quarter(df, col, datetime=True):
     return df
 
 
-def get_drivers_from_api(mds_host, csin, model_version, api_headers, logger):
+def get_sample_drivers(ticker: str):
+    """
+    Return the drivers for the sample models
+    """
+    driver_path = SAMPLE_MODEL_PATH["drivers_path"]
+    path_name = f"{driver_path}/{ticker}_drivers.json"
+    with open(path_name, "r") as file:
+        json_data = json.load(file)
+    return json_data["results"]
+
+
+def get_drivers_from_api(
+    mds_host, csin, model_version, api_headers, logger, verify_ssl
+):
     """
     Returns a list of drivers for the model with the specified CSIN and model version
     """
     driver_list = []
 
     forecast_period_name = get_forecast_period_name(
-        mds_host, csin, model_version, api_headers, logger
+        mds_host, csin, model_version, api_headers, logger, verify_ssl
     )
 
     driver_url = "api/equity-model-series/{csin}/equity-models/{model_version}/forecast-periods/{period}/data-points/?is_driver=true&page_size=200"
@@ -1484,7 +1571,9 @@ def get_drivers_from_api(mds_host, csin, model_version, api_headers, logger):
     next_url: Optional[str] = driver_endpoint
 
     while next_url is not None:
-        json = get_request_json_content(next_url, headers=api_headers, logger=logger)
+        json = get_request_json_content(
+            next_url, headers=api_headers, logger=logger, verify_ssl=verify_ssl
+        )
         drivers = json.get("results")
         next_url = json.get("next")
         driver_list.extend(drivers)
@@ -1492,7 +1581,14 @@ def get_drivers_from_api(mds_host, csin, model_version, api_headers, logger):
     return driver_list
 
 
-def get_forecast_period_name(mds_host, csin, model_version, api_headers, logger):
+def get_forecast_period_name(
+    mds_host,
+    csin,
+    model_version,
+    api_headers,
+    logger,
+    verify_ssl=settings.VERIFY_SSL,
+):
     """
     Retrieve the first forecast period name
     """
@@ -1506,20 +1602,22 @@ def get_forecast_period_name(mds_host, csin, model_version, api_headers, logger)
         print(f"Candas: Error with getting forecast period.")
         return
 
-    response_content = get_request_json_content(forecast_endpoint, api_headers, logger)
+    response_content = get_request_json_content(
+        forecast_endpoint, api_headers, logger, verify_ssl
+    )
 
     forecast_period_name = response_content["results"][0]["name"]
 
     return forecast_period_name
 
 
-def get_request_json_content(url, headers, logger):
+def get_request_json_content(url, headers, logger, verify_ssl=settings.VERIFY_SSL):
     """
     Make a GET request to a URL that responds with JSON content
 
     Returns the deserialized response content
     """
-    return get_request(url, headers, logger).json()
+    return get_request(url, headers, logger, verify_ssl).json()
 
 
 def get_chart_brand_config(
